Exception: Apartment::FileNotFound
- Inherits:
-
ApartmentError
- Object
- StandardError
- ApartmentError
- Apartment::FileNotFound
- Defined in:
- lib/apartment.rb
Overview
Raised when apartment cannot find the file to be loaded
Raised when apartment cannot find the file to be loaded